@@ -30,6 +30,7 @@
 #include "KDbConnection.h"
 #include "KDbDriverManager.h"
 #include "KDbUtils.h"
+#include "KDbUtils_p.h"
 #include "kdb_debug.h"
 #include "config-kdb.h"
 
@@ -39,6 +40,9 @@
 #include <QFile>
 #include <QFileInfo>
 
+static const int SQUEEZED_TEXT_LIMIT = 1024;
+static const int SQUEEZED_TEXT_SUFFIX = 24;
+
 #ifdef Q_OS_WIN
 #include <windows.h>
 #ifdef _WIN32_WCE
@@ -152,7 +156,7 @@ void* KDbUtils::stringToPointerInternal(const QString& string, int size)
     array.resize(size);
     bool ok;
     for (int i = 0; i < size; i++) {
-        array[i] = (unsigned char)(string.mid(i * 2, 2).toUInt(&ok, 16));
+        array[i] = (unsigned char)(string.midRef(i * 2, 2).toUInt(&ok, 16));
         if (!ok)
             return nullptr;
     }
@@ -329,7 +333,7 @@ static QString tildeExpand(const QString &fname)
         int pos = fname.indexOf( QLatin1Char('/') );
         QString ret = QDir::homePath(); // simplified
         if (pos > 0) {
-            ret += fname.mid(pos);
+            ret += fname.midRef(pos);
         }
         return ret;
     } else if (fname.length() > 1 && fname[0] == QLatin1Char(ESCAPE) && fname[1] == QLatin1Char('~')) {
@@ -399,7 +403,6 @@ QString KDbUtils::findExe(const QString& appname,
         return QString();
     }
 #endif
-    QFileInfo info;
 
     // absolute or relative path?
     if (appname.contains(QDir::separator())) {
@@ -493,3 +496,30 @@ QList<QByteArray> PropertySet::names() const
 {
     return d->data.keys();
 }
+
+QVariant KDbUtilsInternal::squeezedValue(const QVariant &value)
+{
+    switch(value.type()) {
+    case QVariant::String:
+        if (value.toString().length() > SQUEEZED_TEXT_LIMIT) {
+            return QVariant(value.toString().left(SQUEEZED_TEXT_LIMIT - SQUEEZED_TEXT_SUFFIX)
+                    + QString::fromLatin1("...")
+                    + value.toString().right(SQUEEZED_TEXT_SUFFIX)
+                    + QString::fromLatin1("[%1 characters]").arg(value.toString().length()));
+        }
+        break;
+    case QVariant::ByteArray:
+        if (value.toByteArray().length() > SQUEEZED_TEXT_LIMIT) {
+            return QVariant(value.toByteArray().left(SQUEEZED_TEXT_LIMIT - SQUEEZED_TEXT_SUFFIX)
+                    + "..."
+                    + value.toByteArray().right(SQUEEZED_TEXT_SUFFIX)
+                    + '[' + QByteArray::number(value.toByteArray().length())
+                    + " bytes]");
+        }
+        break;
+    default:
+        break;
+    }
+//! @todo add BitArray, Url, Hash, Map, Pixmap, Image?
+    return value;
+}
